==> developer-center-biz-1.0.8.zhengjy-20160811.083359-3-sources.jar: cn/com/duiba/developer/center/biz/entity/RechargeOrdersEntity.java <==
package cn.com.duiba.developer.center.biz.entity;

import java.util.Date;
/**
 * 充值订单Entity
 * Name：cn.com.duiba.developer.center.api.domain.dataobject.RechargeOrdersDto.java
 * Description：
 * Author：zhengjy
 * Create Time：2016年7月25日 下午3:29:53
 */
public class RechargeOrdersEntity {
	private Long id;
	private String orderNum;// 订单号
	private Long devId;// 开发者ID

	private String devIp; // 充值用户IP
	private String defaultBank;// 默认银行

	private String type;// 充值类型 贝付科技：ebatong

	private Long totalFee; // 总价 单位分 上游提交的金额 包含手续费
	private Long chargeMoney; // 充值金额
	private String payUrl;// 充值连接
	private String tradeStatus;// 上游处理状态
	private String tradeNo;// 上游订单号
	private String supplierInfo;

	private String status;// 处理中 成功 失败
	private String errorMessage;// 系统错误
	private String failReason;// 失败原因，主要是给用户看的

	private Date finishTime; // 订单结束时间

	private String brief;

	private String json;//拓展字段,数据库长度255,当前使用最多90

	private Date gmtCreate;
	private Date gmtModified;

	public String getOrderNum() {
		return orderNum;
	}

	public void setOrderNum(String orderNum) {
		this.orderNum = orderNum;
	}

	public Long getDevId() {
		return devId;
	}

	public void setDevId(Long devId) {
		this.devId = devId;
	}

	public String getDevIp() {
		return devIp;
	}

	public void setDevIp(String devIp) {
		this.devIp = devIp;
	}

	public String getDefaultBank() {
		return defaultBank;
	}

	public void setDefaultBank(String defaultBank) {
		this.defaultBank = defaultBank;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public Long getTotalFee() {
		return totalFee;
	}

	public void setTotalFee(Long totalFee) {
		this.totalFee = totalFee;
	}

	public Long getChargeMoney() {
		return chargeMoney;
	}

	public void setChargeMoney(Long chargeMoney) {
		this.chargeMoney = chargeMoney;
	}

	public String getPayUrl() {
		return payUrl;
	}

	public void setPayUrl(String payUrl) {
		this.payUrl = payUrl;
	}

	public String getTradeStatus() {
		return tradeStatus;
	}

	public void setTradeStatus(String tradeStatus) {
		this.tradeStatus = tradeStatus;
	}

	public String getTradeNo() {
		return tradeNo;
	}

	public void setTradeNo(String tradeNo) {
		this.tradeNo = tradeNo;
	}

	public String getSupplierInfo() {
		return supplierInfo;
	}

	public void setSupplierInfo(String supplierInfo) {
		this.supplierInfo = supplierInfo;
	}

	public String getStatus() {
		return status;
	}

	public void setStatus(String status) {
		this.status = status;
	}

	public String getErrorMessage() {
		return errorMessage;
	}

	public void setErrorMessage(String errorMessage) {
		this.errorMessage = errorMessage;
	}

	public String getFailReason() {
		return failReason;
	}

	public void setFailReason(String failReason) {
		this.failReason = failReason;
	}

	public Date getFinishTime() {
		return finishTime;
	}

	public void setFinishTime(Date finishTime) {
		this.finishTime = finishTime;
	}

	public String getBrief() {
		return brief;
	}

	public void setBrief(String brief) {
		this.brief = brief;
	}

	public String getJson() {
		return json;
	}

	public void setJson(String json) {
		this.json = json;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

	public Long getId() {
	    return id;
    }

	public void setId(Long id) {
	    this.id = id;
    }
}

==> developer-center-biz-1.3.4-zhengjy5.20161115.065329-1-sources.jar: cn/com/duiba/developer/center/biz/entity/RechargeOrdersEntity.java <==
package cn.com.duiba.developer.center.biz.entity;

import java.util.Date;
/**
 * 充值订单Entity
 * Name：cn.com.duiba.developer.center.api.domain.dataobject.RechargeOrdersDto.java
 * Description：
 * Author：zhengjy
 * Create Time：2016年7月25日 下午3:29:53
 */
public class RechargeOrdersEntity extends BaseEntity {
	private Long id;
	private String orderNum;// 订单号
	private Long devId;// 开发者ID

	private String devIp; // 充值用户IP
	private String defaultBank;// 默认银行

	private String type;// 充值类型 贝付科技：ebatong

	private Long totalFee; // 总价 单位分 上游提交的金额 包含手续费
	private Long chargeMoney; // 充值金额
	private String payUrl;// 充值连接
	private String tradeStatus;// 上游处理状态
	private String tradeNo;// 上游订单号
	private String supplierInfo;

	private String status;// 处理中 成功 失败
	private String errorMessage;// 系统错误
	private String failReason;// 失败原因，主要是给用户看的

	private Date finishTime; // 订单结束时间

	private String brief;

	private String json;//拓展字段,数据库长度255,当前使用最多90

	private Date gmtCreate;
	private Date gmtModified;

	public String getOrderNum() {
		return orderNum;
	}

	public void setOrderNum(String orderNum) {
		this.orderNum = orderNum;
	}

	public Long getDevId() {
		return devId;
	}

	public void setDevId(Long devId) {
		this.devId = devId;
	}

	public String getDevIp() {
		return devIp;
	}

	public void setDevIp(String devIp) {
		this.devIp = devIp;
	}

	public String getDefaultBank() {
		return defaultBank;
	}

	public void setDefaultBank(String defaultBank) {
		this.defaultBank = defaultBank;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public Long getTotalFee() {
		return totalFee;
	}

	public void setTotalFee(Long totalFee) {
		this.totalFee = totalFee;
	}

	public Long getChargeMoney() {
		return chargeMoney;
	}

	public void setChargeMoney(Long chargeMoney) {
		this.chargeMoney = chargeMoney;
	}

	public String getPayUrl() {
		return payUrl;
	}

	public void setPayUrl(String payUrl) {
		this.payUrl = payUrl;
	}

	public String getTradeStatus() {
		return tradeStatus;
	}

	public void setTradeStatus(String tradeStatus) {
		this.tradeStatus = tradeStatus;
	}

	public String getTradeNo() {
		return tradeNo;
	}

	public void setTradeNo(String tradeNo) {
		this.tradeNo = tradeNo;
	}

	public String getSupplierInfo() {
		return supplierInfo;
	}

	public void setSupplierInfo(String supplierInfo) {
		this.supplierInfo = supplierInfo;
	}

	public String getStatus() {
		return status;
	}

	public void setStatus(String status) {
		this.status = status;
	}

	public String getErrorMessage() {
		return errorMessage;
	}

	public void setErrorMessage(String errorMessage) {
		this.errorMessage = errorMessage;
	}

	public String getFailReason() {
		return failReason;
	}

	public void setFailReason(String failReason) {
		this.failReason = failReason;
	}

	public Date getFinishTime() {
		return finishTime;
	}

	public void setFinishTime(Date finishTime) {
		this.finishTime = finishTime;
	}

	public String getBrief() {
		return brief;
	}

	public void setBrief(String brief) {
		this.brief = brief;
	}

	public String getJson() {
		return json;
	}

	public void setJson(String json) {
		this.json = json;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

	public Long getId() {
	    return id;
    }

	public void setId(Long id) {
	    this.id = id;
    }
}
